View source: R/weight_operators.R
| as_weight_operator | R Documentation |
Returns a closure that applies a weight matrix W or its transformations (square root, inverse, or combinations thereof) to vectors/matrices.
as_weight_operator(W, transpose = FALSE, sqrt = FALSE, inverse = FALSE)
W |
A weight matrix (symmetric PSD) or NULL for identity |
transpose |
Logical, whether to transpose W before applying |
sqrt |
Logical, whether to use square root of W |
inverse |
Logical, whether to use inverse of W |
A function that applies the requested transformation
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.