genpca_cov_geigen: Generalized eigenvalue-based covariance GPCA (internal)

View source: R/gpca_cov.R

genpca_cov_geigenR Documentation

Generalized eigenvalue-based covariance GPCA (internal)

Description

Solves the generalized eigenproblem projected onto the retained range of R. This is the original implementation that was in gpca.R.

Usage

genpca_cov_geigen(
  C,
  R = NULL,
  ncomp = NULL,
  constraints_remedy = c("error", "ridge", "clip", "identity"),
  rank_rtol = 1e-06,
  metric_rtol = .metric_rtol_default(),
  verbose = FALSE
)

genpca documentation built on Sept. 17, 2026, 1:09 a.m.