gmd_clear_cache: Clear internal cache for matrix decompositions

View source: R/gmd_cache.R

gmd_clear_cacheR Documentation

Clear internal cache for matrix decompositions

Description

Clears the internal cache used by generalized matrix decomposition functions. This can be useful to free up memory or when working with different datasets.

Usage

gmd_clear_cache()

Value

Invisibly returns TRUE after clearing the cache.

Examples

# Clear the internal cache
gmd_clear_cache()


genpca documentation built on Sept. 17, 2026, 1:09 a.m.