| genpca_cov_geigen | R Documentation |
Solves the generalized eigenproblem projected onto the retained range of R. This is the original implementation that was in gpca.R.
genpca_cov_geigen(
C,
R = NULL,
ncomp = NULL,
constraints_remedy = c("error", "ridge", "clip", "identity"),
rank_rtol = 1e-06,
metric_rtol = .metric_rtol_default(),
verbose = FALSE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.