| gmd_clear_cache | R Documentation |
Clears the internal cache used by generalized matrix decomposition functions. This can be useful to free up memory or when working with different datasets.
gmd_clear_cache()
Invisibly returns TRUE after clearing the cache.
# Clear the internal cache
gmd_clear_cache()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.